@@ -36,18 +36,38 @@ tex_replacements = [
     ('±', r'\(\pm\)'),
     ('→', r'\(\rightarrow\)'),
     ('‣', r'\(\rightarrow\)'),
+    ('✓', r'\(\checkmark\)'),
     # used to separate -- in options
     ('﻿', r'{}'),
     # map some special Unicode characters to similar ASCII ones
     ('─', r'-'),
     ('⎽', r'\_'),
     ('╲', r'\textbackslash{}'),
+    ('–', r'\textendash{}'),
     ('|', r'\textbar{}'),
     ('│', r'\textbar{}'),
     ('ℯ', r'e'),
     ('ⅈ', r'i'),
-    ('₁', r'1'),
-    ('₂', r'2'),
+    ('⁰', r'\(\sp{\text{0}}\)'),
+    ('¹', r'\(\sp{\text{1}}\)'),
+    ('²', r'\(\sp{\text{2}}\)'),
+    ('³', r'\(\sp{\text{3}}\)'),
+    ('⁴', r'\(\sp{\text{4}}\)'),
+    ('⁵', r'\(\sp{\text{5}}\)'),
+    ('⁶', r'\(\sp{\text{6}}\)'),
+    ('⁷', r'\(\sp{\text{7}}\)'),
+    ('⁸', r'\(\sp{\text{8}}\)'),
+    ('⁹', r'\(\sp{\text{9}}\)'),
+    ('₀', r'\(\sb{\text{0}}\)'),
+    ('₁', r'\(\sb{\text{1}}\)'),
+    ('₂', r'\(\sb{\text{2}}\)'),
+    ('₃', r'\(\sb{\text{3}}\)'),
+    ('₄', r'\(\sb{\text{4}}\)'),
+    ('₅', r'\(\sb{\text{5}}\)'),
+    ('₆', r'\(\sb{\text{6}}\)'),
+    ('₇', r'\(\sb{\text{7}}\)'),
+    ('₈', r'\(\sb{\text{8}}\)'),
+    ('₉', r'\(\sb{\text{9}}\)'),
     # map Greek alphabet
     ('α', r'\(\alpha\)'),
     ('β', r'\(\beta\)'),
