@@ -13,18 +13,23 @@ from __future__ import print_function
 
 import os
 import sys
+import warnings
 import traceback
 
 from path import path
-import nose
 
 testroot = os.path.dirname(__file__) or '.'
 sys.path.insert(0, os.path.abspath(os.path.join(testroot, os.path.pardir)))
 
+# filter warnings of test dependencies
+warnings.filterwarnings('ignore', category=DeprecationWarning, module='site')  # virtualenv
+warnings.filterwarnings('ignore', category=ImportWarning, module='backports')
+warnings.filterwarnings('ignore', category=PendingDeprecationWarning, module=r'_pytest\..*')
+
 # check dependencies before testing
 print('Checking dependencies...')
-for modname in ('nose', 'mock', 'six', 'docutils', 'jinja2', 'pygments',
-                'snowballstemmer', 'babel'):
+for modname in ('pytest', 'mock', 'six', 'docutils', 'jinja2', 'pygments',
+                'snowballstemmer', 'babel', 'html5lib'):
     try:
         __import__(modname)
     except ImportError as err:
@@ -48,4 +53,14 @@ tempdir.makedirs()
 print('Running Sphinx test suite (with Python %s)...' % sys.version.split()[0])
 sys.stdout.flush()
 
-nose.main()
+# exclude 'root' and 'roots' dirs for pytest test collector
+ignore_paths = [
+    os.path.relpath(os.path.join(os.path.dirname(os.path.abspath(__file__)), sub))
+    for sub in ('root', 'roots')
+]
+args = sys.argv[1:]
+for ignore_path in ignore_paths:
+    args.extend(['--ignore', ignore_path])
+
+import pytest  # NOQA
+sys.exit(pytest.main(args))
