@@ -9,15 +9,15 @@
     :license: BSD, see LICENSE for details.
 """
 
-from xml.etree import ElementTree
+import pytest
 
-from util import with_app
+from util import etree_parse
 
 
-@with_app('xml', testroot='directive-code')
+@pytest.mark.sphinx('xml', testroot='directive-code')
 def test_code_block(app, status, warning):
     app.builder.build('index')
-    et = ElementTree.parse(app.outdir / 'index.xml')
+    et = etree_parse(app.outdir / 'index.xml')
     secs = et.findall('./section/section')
     code_block = secs[0].findall('literal_block')
     assert len(code_block) > 0
@@ -30,10 +30,10 @@ def test_code_block(app, status, warning):
     assert actual == expect
 
 
-@with_app('xml', testroot='directive-code')
+@pytest.mark.sphinx('xml', testroot='directive-code')
 def test_code_block_dedent(app, status, warning):
     app.builder.build(['dedent_code'])
-    et = ElementTree.parse(app.outdir / 'dedent_code.xml')
+    et = etree_parse(app.outdir / 'dedent_code.xml')
     blocks = et.findall('./section/section/literal_block')
 
     for i in range(5):  # 0-4
@@ -49,7 +49,7 @@ def test_code_block_dedent(app, status, warning):
     assert blocks[5].text == '\n\n'   # dedent: 1000
 
 
-@with_app('html', testroot='directive-code')
+@pytest.mark.sphinx('html', testroot='directive-code')
 def test_code_block_caption_html(app, status, warning):
     app.builder.build(['caption'])
     html = (app.outdir / 'caption.html').text(encoding='utf-8')
@@ -61,39 +61,40 @@ def test_code_block_caption_html(app, status, warning):
     assert caption in html
 
 
-@with_app('latex', testroot='directive-code')
+@pytest.mark.sphinx('latex', testroot='directive-code')
 def test_code_block_caption_latex(app, status, warning):
     app.builder.build_all()
     latex = (app.outdir / 'Python.tex').text(encoding='utf-8')
-    caption = '\\sphinxSetupCaptionForVerbatim{literal-block}{caption \\emph{test} rb}'
-    label = '\\def\\sphinxLiteralBlockLabel{\\label{caption:id1}}'
-    link  = '\hyperref[caption:name-test-rb]' \
-            '{Listing \\ref{caption:name-test-rb}}'
+    caption = '\\sphinxSetupCaptionForVerbatim{caption \\sphinxstyleemphasis{test} rb}'
+    label = '\\def\\sphinxLiteralBlockLabel{\\label{\\detokenize{caption:id1}}}'
+    link = '\hyperref[\\detokenize{caption:name-test-rb}]' \
+           '{Listing \\ref{\\detokenize{caption:name-test-rb}}}'
     assert caption in latex
     assert label in latex
     assert link in latex
 
 
-@with_app('latex', testroot='directive-code')
+@pytest.mark.sphinx('latex', testroot='directive-code')
 def test_code_block_namedlink_latex(app, status, warning):
     app.builder.build_all()
     latex = (app.outdir / 'Python.tex').text(encoding='utf-8')
-    label1 = '\def\sphinxLiteralBlockLabel{\label{caption:name-test-rb}}'
-    link1  = '\\hyperref[caption:name\\string-test\\string-rb]'\
-             '{\\sphinxcrossref{\\DUrole{std,std-ref}{Ruby}}'
-    label2 = '\def\sphinxLiteralBlockLabel{\label{namedblocks:some-ruby-code}}'
-    link2  = '\\hyperref[namedblocks:some\\string-ruby\\string-code]'\
-             '{\\sphinxcrossref{\\DUrole{std,std-ref}{the ruby code}}}'
+    label1 = '\\def\\sphinxLiteralBlockLabel{\\label{\\detokenize{caption:name-test-rb}}}'
+    link1 = '\\hyperref[\\detokenize{caption:name-test-rb}]'\
+            '{\\sphinxcrossref{\\DUrole{std,std-ref}{Ruby}}'
+    label2 = ('\\def\\sphinxLiteralBlockLabel'
+              '{\\label{\\detokenize{namedblocks:some-ruby-code}}}')
+    link2 = '\\hyperref[\\detokenize{namedblocks:some-ruby-code}]'\
+            '{\\sphinxcrossref{\\DUrole{std,std-ref}{the ruby code}}}'
     assert label1 in latex
     assert link1 in latex
     assert label2 in latex
     assert link2 in latex
 
 
-@with_app('xml', testroot='directive-code')
+@pytest.mark.sphinx('xml', testroot='directive-code')
 def test_literal_include(app, status, warning):
     app.builder.build(['index'])
-    et = ElementTree.parse(app.outdir / 'index.xml')
+    et = etree_parse(app.outdir / 'index.xml')
     secs = et.findall('./section/section')
     literal_include = secs[1].findall('literal_block')
     literal_src = (app.srcdir / 'literal.inc').text(encoding='utf-8')
@@ -102,13 +103,13 @@ def test_literal_include(app, status, warning):
     assert actual == literal_src
 
 
-@with_app('xml', testroot='directive-code')
+@pytest.mark.sphinx('xml', testroot='directive-code')
 def test_literal_include_dedent(app, status, warning):
     literal_src = (app.srcdir / 'literal.inc').text(encoding='utf-8')
     literal_lines = [l[4:] for l in literal_src.split('\n')[9:11]]
 
     app.builder.build(['dedent'])
-    et = ElementTree.parse(app.outdir / 'dedent.xml')
+    et = etree_parse(app.outdir / 'dedent.xml')
     blocks = et.findall('./section/section/literal_block')
 
     for i in range(5):  # 0-4
@@ -120,10 +121,10 @@ def test_literal_include_dedent(app, status, warning):
     assert blocks[5].text == '\n\n'   # dedent: 1000
 
 
-@with_app('xml', testroot='directive-code')
+@pytest.mark.sphinx('xml', testroot='directive-code')
 def test_literal_include_block_start_with_comment_or_brank(app, status, warning):
     app.builder.build(['python'])
-    et = ElementTree.parse(app.outdir / 'python.xml')
+    et = etree_parse(app.outdir / 'python.xml')
     secs = et.findall('./section/section')
     literal_include = secs[0].findall('literal_block')
     assert len(literal_include) > 0
@@ -144,7 +145,7 @@ def test_literal_include_block_start_with_comment_or_brank(app, status, warning)
     assert actual == expect
 
 
-@with_app('html', testroot='directive-code')
+@pytest.mark.sphinx('html', testroot='directive-code')
 def test_literal_include_linenos(app, status, warning):
     app.builder.build(['linenos'])
     html = (app.outdir / 'linenos.html').text(encoding='utf-8')
@@ -167,7 +168,7 @@ def test_literal_include_linenos(app, status, warning):
     assert linenos in html
 
 
-@with_app('html', testroot='directive-code')
+@pytest.mark.sphinx('html', testroot='directive-code')
 def test_literal_include_lineno_start(app, status, warning):
     app.builder.build(['lineno_start'])
     html = (app.outdir / 'lineno_start.html').text(encoding='utf-8')
@@ -190,7 +191,7 @@ def test_literal_include_lineno_start(app, status, warning):
     assert linenos in html
 
 
-@with_app('html', testroot='directive-code')
+@pytest.mark.sphinx('html', testroot='directive-code')
 def test_literal_include_lineno_match(app, status, warning):
     app.builder.build(['lineno_match'])
     html = (app.outdir / 'lineno_match.html').text(encoding='utf-8')
@@ -222,21 +223,29 @@ def test_literal_include_lineno_match(app, status, warning):
         '14</pre></div></td>')
     assert start_after in html
 
+    start_at_end_at = (
+        '<td class="linenos"><div class="linenodiv"><pre>'
+        ' 9\n'
+        '10\n'
+        '11</pre></div></td>')
+    assert start_at_end_at in html
 
-@with_app('latex', testroot='directive-code')
+
+@pytest.mark.sphinx('latex', testroot='directive-code')
 def test_literalinclude_file_whole_of_emptyline(app, status, warning):
     app.builder.build_all()
     latex = (app.outdir / 'Python.tex').text(encoding='utf-8').replace('\r\n', '\n')
     includes = (
-        '\\begin{Verbatim}[commandchars=\\\\\\{\\},numbers=left,firstnumber=1,stepnumber=1]\n'
+        '\\begin{sphinxVerbatim}'
+        '[commandchars=\\\\\\{\\},numbers=left,firstnumber=1,stepnumber=1]\n'
         '\n'
         '\n'
         '\n'
-        '\\end{Verbatim}\n')
+        '\\end{sphinxVerbatim}\n')
     assert includes in latex
 
 
-@with_app('html', testroot='directive-code')
+@pytest.mark.sphinx('html', testroot='directive-code')
 def test_literalinclude_caption_html(app, status, warning):
     app.builder.build('index')
     html = (app.outdir / 'caption.html').text(encoding='utf-8')
@@ -248,39 +257,40 @@ def test_literalinclude_caption_html(app, status, warning):
     assert caption in html
 
 
-@with_app('latex', testroot='directive-code')
+@pytest.mark.sphinx('latex', testroot='directive-code')
 def test_literalinclude_caption_latex(app, status, warning):
     app.builder.build('index')
     latex = (app.outdir / 'Python.tex').text(encoding='utf-8')
-    caption = '\\sphinxSetupCaptionForVerbatim{literal-block}{caption \\textbf{test} py}'
-    label = '\\def\\sphinxLiteralBlockLabel{\\label{caption:id2}}'
-    link  = '\hyperref[caption:name-test-py]' \
-            '{Listing \\ref{caption:name-test-py}}'
+    caption = '\\sphinxSetupCaptionForVerbatim{caption \\sphinxstylestrong{test} py}'
+    label = '\\def\\sphinxLiteralBlockLabel{\\label{\\detokenize{caption:id2}}}'
+    link = '\hyperref[\\detokenize{caption:name-test-py}]' \
+           '{Listing \\ref{\\detokenize{caption:name-test-py}}}'
     assert caption in latex
     assert label in latex
     assert link in latex
 
 
-@with_app('latex', testroot='directive-code')
+@pytest.mark.sphinx('latex', testroot='directive-code')
 def test_literalinclude_namedlink_latex(app, status, warning):
     app.builder.build('index')
     latex = (app.outdir / 'Python.tex').text(encoding='utf-8')
-    label1 = '\def\sphinxLiteralBlockLabel{\label{caption:name-test-py}}'
-    link1  = '\\hyperref[caption:name\\string-test\\string-py]'\
-             '{\\sphinxcrossref{\\DUrole{std,std-ref}{Python}}'
-    label2 = '\def\sphinxLiteralBlockLabel{\label{namedblocks:some-python-code}}'
-    link2  = '\\hyperref[namedblocks:some\\string-python\\string-code]'\
-             '{\\sphinxcrossref{\\DUrole{std,std-ref}{the python code}}}'
+    label1 = '\\def\\sphinxLiteralBlockLabel{\\label{\\detokenize{caption:name-test-py}}}'
+    link1 = '\\hyperref[\\detokenize{caption:name-test-py}]'\
+            '{\\sphinxcrossref{\\DUrole{std,std-ref}{Python}}'
+    label2 = ('\\def\\sphinxLiteralBlockLabel'
+              '{\\label{\\detokenize{namedblocks:some-python-code}}}')
+    link2 = '\\hyperref[\\detokenize{namedblocks:some-python-code}]'\
+            '{\\sphinxcrossref{\\DUrole{std,std-ref}{the python code}}}'
     assert label1 in latex
     assert link1 in latex
     assert label2 in latex
     assert link2 in latex
 
 
-@with_app('xml', testroot='directive-code')
+@pytest.mark.sphinx('xml', testroot='directive-code')
 def test_literalinclude_classes(app, status, warning):
     app.builder.build(['classes'])
-    et = ElementTree.parse(app.outdir / 'classes.xml')
+    et = etree_parse(app.outdir / 'classes.xml')
     secs = et.findall('./section/section')
 
     code_block = secs[0].findall('literal_block')
