@@ -12,11 +12,11 @@
 import re
 
 from docutils import nodes
-
-from util import with_app
+from sphinx.util.nodes import process_only_nodes
+import pytest
 
 
-@with_app('text', testroot='directive-only')
+@pytest.mark.sphinx('text', testroot='directive-only')
 def test_sectioning(app, status, warning):
 
     def getsects(section):
@@ -42,15 +42,15 @@ def test_sectioning(app, status, warning):
             num = subsect[0].split()[0]
             assert re.match('[0-9]+[.0-9]*[.]', num), \
                 'Unnumbered section: %r' % subsect[0]
-            testsects(prefix + str(i+1) + '.', subsect, indent+4)
+            testsects(prefix + str(i + 1) + '.', subsect, indent + 4)
 
     app.builder.build(['only'])
     doctree = app.env.get_doctree('only')
-    app.env.process_only_nodes(doctree, app.builder)
+    process_only_nodes(doctree, app.builder.tags)
 
     parts = [getsects(n)
              for n in [_n for _n in doctree.children if isinstance(_n, nodes.section)]]
     for i, s in enumerate(parts):
-        testsects(str(i+1) + '.', s, 4)
+        testsects(str(i + 1) + '.', s, 4)
     assert len(parts) == 4, 'Expected 4 document level headings, got:\n%s' % \
         '\n'.join([p[0] for p in parts])
