@@ -12,8 +12,7 @@
 import re
 
 from six import text_type
-
-from util import raises, with_app
+import pytest
 
 from sphinx import addnodes
 from sphinx.domains.cpp import DefinitionParser, DefinitionError, NoOldIdError
@@ -24,12 +23,15 @@ ids = []
 
 
 def parse(name, string):
-    parser = DefinitionParser(string, None)
+    class Config(object):
+        cpp_id_attributes = ["id_attr"]
+        cpp_paren_attributes = ["paren_attr"]
+    parser = DefinitionParser(string, None, Config())
     ast = parser.parse_declaration(name)
     if not parser.eof:
         print("Parsing stopped at", parser.pos)
         print(string)
-        print('-'*parser.pos + '^')
+        print('-' * parser.pos + '^')
         raise DefinitionError("")
     # The scopedness would usually have been set by CPPEnumObject
     if name == "enum":
@@ -50,7 +52,7 @@ def check(name, input, idv1output=None, idv2output=None, output=None):
         print("Expected: ", output)
         raise DefinitionError("")
     rootSymbol = Symbol(None, None, None, None, None, None)
-    symbol = rootSymbol.add_declaration(ast, docname="Test")
+    symbol = rootSymbol.add_declaration(ast, docname="TestDoc")
     parentNode = addnodes.desc()
     signode = addnodes.desc_signature(input, '')
     parentNode += signode
@@ -138,6 +140,21 @@ def test_type_definitions():
     check('type', 'void (*f)(std::function<void(int i)> g)', 'f', '1f')
 
 
+def test_concept_definitions():
+    check('concept', 'template<typename Param> A::B::Concept',
+          None, 'I0EN1A1B7ConceptE')
+    check('concept', 'template<typename A, typename B, typename ...C> Foo',
+          None, 'I00DpE3Foo')
+    check('concept', 'template<typename Param> A::B::Concept()',
+          None, 'I0EN1A1B7ConceptE')
+    check('concept', 'template<typename A, typename B, typename ...C> Foo()',
+          None, 'I00DpE3Foo')
+    with pytest.raises(DefinitionError):
+        parse('concept', 'Foo')
+    with pytest.raises(DefinitionError):
+        parse('concept', 'template<typename T> template<typename U> Foo')
+
+
 def test_member_definitions():
     check('member', '  const  std::string  &  name = 42',
           "name__ssCR", "4name", output='const std::string &name = 42')
@@ -242,9 +259,12 @@ def test_function_definitions():
           'int foo(Foo f = Foo(double(), std::make_pair(int(2), double(3.4))))',
           "foo__Foo", "3foo3Foo")
     check('function', 'int foo(A a = x(a))', "foo__A", "3foo1A")
-    raises(DefinitionError, parse, 'function', 'int foo(B b=x(a)')
-    raises(DefinitionError, parse, 'function', 'int foo)C c=x(a))')
-    raises(DefinitionError, parse, 'function', 'int foo(D d=x(a')
+    with pytest.raises(DefinitionError):
+        parse('function', 'int foo(B b=x(a)')
+    with pytest.raises(DefinitionError):
+        parse('function', 'int foo)C c=x(a))')
+    with pytest.raises(DefinitionError):
+        parse('function', 'int foo(D d=x(a')
     check('function', 'int foo(const A&... a)', "foo__ACRDp", "3fooDpRK1A")
     check('function', 'virtual void f()', "f", "1fv")
     # test for ::nestedName, from issue 1738
@@ -365,8 +385,10 @@ def test_templates():
     check('function', "template<> void A()", None, "IE1Av")
     check('member', "template<> A a", None, "IE1a")
     check('type', "template<> a = A", None, "IE1a")
-    raises(DefinitionError, parse, 'enum', "template<> A")
-    raises(DefinitionError, parse, 'enumerator', "template<> A")
+    with pytest.raises(DefinitionError):
+        parse('enum', "template<> A")
+    with pytest.raises(DefinitionError):
+        parse('enumerator', "template<> A")
     # then all the real tests
     check('class', "template<typename T1, typename T2> A", None, "I00E1A")
     check('type', "template<> a", None, "IE1a")
@@ -401,6 +423,77 @@ def test_templates():
           None, "I00ElsRNSt13basic_ostreamI4Char6TraitsEE"
           "RK18c_string_view_baseIK4Char6TraitsE")
 
+    # template introductions
+    with pytest.raises(DefinitionError):
+        parse('enum', 'abc::ns::foo{id_0, id_1, id_2} A')
+    with pytest.raises(DefinitionError):
+        parse('enumerator', 'abc::ns::foo{id_0, id_1, id_2} A')
+    check('class', 'abc::ns::foo{id_0, id_1, id_2} xyz::bar',
+          None, 'I000EXN3abc2ns3fooEI4id_04id_14id_2EEN3xyz3barE')
+    check('class', 'abc::ns::foo{id_0, id_1, ...id_2} xyz::bar',
+          None, 'I00DpEXN3abc2ns3fooEI4id_04id_1sp4id_2EEN3xyz3barE')
+    check('class', 'abc::ns::foo{id_0, id_1, id_2} xyz::bar<id_0, id_1, id_2>',
+          None, 'I000EXN3abc2ns3fooEI4id_04id_14id_2EEN3xyz3barI4id_04id_14id_2EE')
+    check('class', 'abc::ns::foo{id_0, id_1, ...id_2} xyz::bar<id_0, id_1, id_2...>',
+          None, 'I00DpEXN3abc2ns3fooEI4id_04id_1sp4id_2EEN3xyz3barI4id_04id_1Dp4id_2EE')
+
+    check('class', 'template<> Concept{U} A<int>::B',
+          None, 'IEI0EX7ConceptI1UEEN1AIiE1BE')
+
+    check('type', 'abc::ns::foo{id_0, id_1, id_2} xyz::bar = ghi::qux',
+          None, 'I000EXN3abc2ns3fooEI4id_04id_14id_2EEN3xyz3barE')
+    check('type', 'abc::ns::foo{id_0, id_1, ...id_2} xyz::bar = ghi::qux',
+          None, 'I00DpEXN3abc2ns3fooEI4id_04id_1sp4id_2EEN3xyz3barE')
+    check('function', 'abc::ns::foo{id_0, id_1, id_2} void xyz::bar()',
+          None, 'I000EXN3abc2ns3fooEI4id_04id_14id_2EEN3xyz3barEv')
+    check('function', 'abc::ns::foo{id_0, id_1, ...id_2} void xyz::bar()',
+          None, 'I00DpEXN3abc2ns3fooEI4id_04id_1sp4id_2EEN3xyz3barEv')
+    check('member', 'abc::ns::foo{id_0, id_1, id_2} ghi::qux xyz::bar',
+          None, 'I000EXN3abc2ns3fooEI4id_04id_14id_2EEN3xyz3barE')
+    check('member', 'abc::ns::foo{id_0, id_1, ...id_2} ghi::qux xyz::bar',
+          None, 'I00DpEXN3abc2ns3fooEI4id_04id_1sp4id_2EEN3xyz3barE')
+    check('concept', 'Iterator{T, U} Another',
+          None, 'I00EX8IteratorI1T1UEE7Another')
+    check('concept', 'template<typename ...Pack> Numerics = (... && Numeric<Pack>)',
+          None, 'IDpE8Numerics')
+
+
+def test_attributes():
+    # style: C++
+    check('member', '[[]] int f', 'f__i', '1f')
+    check('member', '[ [ ] ] int f', 'f__i', '1f',
+          # this will fail when the proper grammar is implemented
+          output='[[ ]] int f')
+    check('member', '[[a]] int f', 'f__i', '1f')
+    # style: GNU
+    check('member', '__attribute__(()) int f', 'f__i', '1f')
+    check('member', '__attribute__((a)) int f', 'f__i', '1f')
+    check('member', '__attribute__((a, b)) int f', 'f__i', '1f')
+    # style: user-defined id
+    check('member', 'id_attr int f', 'f__i', '1f')
+    # style: user-defined paren
+    check('member', 'paren_attr() int f', 'f__i', '1f')
+    check('member', 'paren_attr(a) int f', 'f__i', '1f')
+    check('member', 'paren_attr("") int f', 'f__i', '1f')
+    check('member', 'paren_attr(()[{}][]{}) int f', 'f__i', '1f')
+    with pytest.raises(DefinitionError):
+        parse('member', 'paren_attr(() int f')
+    with pytest.raises(DefinitionError):
+        parse('member', 'paren_attr([) int f')
+    with pytest.raises(DefinitionError):
+        parse('member', 'paren_attr({) int f')
+    with pytest.raises(DefinitionError):
+        parse('member', 'paren_attr([)]) int f')
+    with pytest.raises(DefinitionError):
+        parse('member', 'paren_attr((])) int f')
+    with pytest.raises(DefinitionError):
+        parse('member', 'paren_attr({]}) int f')
+
+    # position: decl specs
+    check('function', 'static inline __attribute__(()) void f()',
+          'f', '1fv',
+          output='__attribute__(()) static inline void f()')
+
 
 # def test_print():
 #     # used for getting all the ids out for checking
@@ -409,7 +502,7 @@ def test_templates():
 #     raise DefinitionError("")
 
 
-@with_app(testroot='domain-cpp', confoverrides={'add_function_parentheses': True})
+@pytest.mark.sphinx(testroot='domain-cpp', confoverrides={'add_function_parentheses': True})
 def test_build_domain_cpp_with_add_function_parentheses_is_True(app, status, warning):
     app.builder.build_all()
 
@@ -430,7 +523,11 @@ def test_build_domain_cpp_with_add_function_parentheses_is_True(app, status, war
         ('ref function without parens ', 'paren_1\(\)'),
         ('ref function with parens ', 'paren_2\(\)'),
         ('ref function without parens, explicit title ', 'paren_3_title'),
-        ('ref function with parens, explicit title ', 'paren_4_title')
+        ('ref function with parens, explicit title ', 'paren_4_title'),
+        ('ref op call without parens ', 'paren_5::operator\(\)\(\)'),
+        ('ref op call with parens ', 'paren_6::operator\(\)\(\)'),
+        ('ref op call without parens, explicit title ', 'paren_7_title'),
+        ('ref op call with parens, explicit title ', 'paren_8_title')
     ]
 
     f = 'roles.html'
@@ -446,7 +543,8 @@ def test_build_domain_cpp_with_add_function_parentheses_is_True(app, status, war
         check(s, t, f)
 
 
-@with_app(testroot='domain-cpp', confoverrides={'add_function_parentheses': False})
+@pytest.mark.sphinx(testroot='domain-cpp', confoverrides={
+    'add_function_parentheses': False})
 def test_build_domain_cpp_with_add_function_parentheses_is_False(app, status, warning):
     app.builder.build_all()
 
@@ -467,7 +565,11 @@ def test_build_domain_cpp_with_add_function_parentheses_is_False(app, status, wa
         ('ref function without parens ', 'paren_1'),
         ('ref function with parens ', 'paren_2'),
         ('ref function without parens, explicit title ', 'paren_3_title'),
-        ('ref function with parens, explicit title ', 'paren_4_title')
+        ('ref function with parens, explicit title ', 'paren_4_title'),
+        ('ref op call without parens ', 'paren_5::operator\(\)'),
+        ('ref op call with parens ', 'paren_6::operator\(\)'),
+        ('ref op call without parens, explicit title ', 'paren_7_title'),
+        ('ref op call with parens, explicit title ', 'paren_8_title')
     ]
 
     f = 'roles.html'
