@@ -10,37 +10,12 @@
 """
 
 import re
-import subprocess
-from functools import wraps
 
-from util import with_app, SkipTest
+import pytest
 
 
-def skip_if_graphviz_not_found(fn):
-    @wraps(fn)
-    def decorator(app, *args, **kwargs):
-        found = False
-        graphviz_dot = getattr(app.config, 'graphviz_dot', '')
-        try:
-            if graphviz_dot:
-                dot = subprocess.Popen([graphviz_dot, '-V'],
-                                       stdout=subprocess.PIPE,
-                                       stderr=subprocess.PIPE)  # show version
-                dot.wait()
-                found = True
-        except OSError:  # No such file or directory
-            pass
-
-        if not found:
-            raise SkipTest('graphviz "dot" is not available')
-
-        return fn(app, *args, **kwargs)
-
-    return decorator
-
-
-@with_app('html', testroot='ext-graphviz')
-@skip_if_graphviz_not_found
+@pytest.mark.sphinx('html', testroot='ext-graphviz')
+@pytest.mark.usefixtures('if_graphviz_found')
 def test_graphviz_html(app, status, warning):
     app.builder.build_all()
 
@@ -55,9 +30,13 @@ def test_graphviz_html(app, status, warning):
     html = '<img src=".*?" alt="digraph {\n  bar -&gt; baz\n}" />'
     assert re.search(html, content, re.M)
 
+    html = ('<div class="figure align-right" .*?>\s*<img .*?/>\s*<p class="caption">'
+            '<span class="caption-text">on right</span>.*</p>\s*</div>')
+    assert re.search(html, content, re.S)
 
-@with_app('latex', testroot='ext-graphviz')
-@skip_if_graphviz_not_found
+
+@pytest.mark.sphinx('latex', testroot='ext-graphviz')
+@pytest.mark.usefixtures('if_graphviz_found')
 def test_graphviz_latex(app, status, warning):
     app.builder.build_all()
 
@@ -70,9 +49,14 @@ def test_graphviz_latex(app, status, warning):
     macro = 'Hello \\\\includegraphics{graphviz-\w+.pdf} graphviz world'
     assert re.search(macro, content, re.S)
 
+    macro = ('\\\\begin{wrapfigure}{r}{0pt}\n\\\\centering\n'
+             '\\\\includegraphics{graphviz-\w+.pdf}\n'
+             '\\\\caption{on right}\\\\label{.*}\\\\end{wrapfigure}')
+    assert re.search(macro, content, re.S)
 
-@with_app('html', testroot='ext-graphviz', confoverrides={'language': 'xx'})
-@skip_if_graphviz_not_found
+
+@pytest.mark.sphinx('html', testroot='ext-graphviz', confoverrides={'language': 'xx'})
+@pytest.mark.usefixtures('if_graphviz_found')
 def test_graphviz_i18n(app, status, warning):
     app.builder.build_all()
 
