@@ -12,38 +12,35 @@ from __future__ import print_function
 
 import os
 import datetime
-from os import path
 
+import pytest
 from babel.messages.mofile import read_mo
 from sphinx.util import i18n
 from sphinx.errors import SphinxError
 
-from util import TestApp, with_tempdir, raises
-
 
 def test_catalog_info_for_file_and_path():
     cat = i18n.CatalogInfo('path', 'domain', 'utf-8')
     assert cat.po_file == 'domain.po'
     assert cat.mo_file == 'domain.mo'
-    assert cat.po_path == path.join('path', 'domain.po')
-    assert cat.mo_path == path.join('path', 'domain.mo')
+    assert cat.po_path == os.path.join('path', 'domain.po')
+    assert cat.mo_path == os.path.join('path', 'domain.mo')
 
 
 def test_catalog_info_for_sub_domain_file_and_path():
     cat = i18n.CatalogInfo('path', 'sub/domain', 'utf-8')
     assert cat.po_file == 'sub/domain.po'
     assert cat.mo_file == 'sub/domain.mo'
-    assert cat.po_path == path.join('path', 'sub/domain.po')
-    assert cat.mo_path == path.join('path', 'sub/domain.mo')
+    assert cat.po_path == os.path.join('path', 'sub/domain.po')
+    assert cat.mo_path == os.path.join('path', 'sub/domain.mo')
 
 
-@with_tempdir
-def test_catalog_outdated(dir):
-    (dir / 'test.po').write_text('#')
-    cat = i18n.CatalogInfo(dir, 'test', 'utf-8')
+def test_catalog_outdated(tempdir):
+    (tempdir / 'test.po').write_text('#')
+    cat = i18n.CatalogInfo(tempdir, 'test', 'utf-8')
     assert cat.is_outdated()  # if mo is not exist
 
-    mo_file = (dir / 'test.mo')
+    mo_file = (tempdir / 'test.mo')
     mo_file.write_text('#')
     assert not cat.is_outdated()  # if mo is exist and newer than po
 
@@ -51,31 +48,29 @@ def test_catalog_outdated(dir):
     assert cat.is_outdated()  # if mo is exist and older than po
 
 
-@with_tempdir
-def test_catalog_write_mo(dir):
-    (dir / 'test.po').write_text('#')
-    cat = i18n.CatalogInfo(dir, 'test', 'utf-8')
-    cat.write_mo('en')
-    assert path.exists(cat.mo_path)
+def test_catalog_write_mo(tempdir):
+    (tempdir / 'test.po').write_text('#')
+    cat = i18n.CatalogInfo(tempdir, 'test', 'utf-8')
+    cat.write_mo('en', lambda *a, **kw: None)
+    assert os.path.exists(cat.mo_path)
     with open(cat.mo_path, 'rb') as f:
         assert read_mo(f) is not None
 
 
-@with_tempdir
-def test_get_catalogs_for_xx(dir):
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test2.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test3.pot').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub').makedirs()
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test4.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test5.po').write_text('#')
-    (dir / 'loc1' / 'en' / 'LC_MESSAGES').makedirs()
-    (dir / 'loc1' / 'en' / 'LC_MESSAGES' / 'test6.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_ALL').makedirs()
-    (dir / 'loc1' / 'xx' / 'LC_ALL' / 'test7.po').write_text('#')
+def test_get_catalogs_for_xx(tempdir):
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test2.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test3.pot').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub').makedirs()
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test4.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test5.po').write_text('#')
+    (tempdir / 'loc1' / 'en' / 'LC_MESSAGES').makedirs()
+    (tempdir / 'loc1' / 'en' / 'LC_MESSAGES' / 'test6.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_ALL').makedirs()
+    (tempdir / 'loc1' / 'xx' / 'LC_ALL' / 'test7.po').write_text('#')
 
-    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx', force_all=False)
+    catalogs = i18n.find_catalog_source_files([tempdir / 'loc1'], 'xx', force_all=False)
     domains = set(c.domain for c in catalogs)
     assert domains == set([
         'test1',
@@ -85,24 +80,22 @@ def test_get_catalogs_for_xx(dir):
     ])
 
 
-@with_tempdir
-def test_get_catalogs_for_en(dir):
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'xx_dom.po').write_text('#')
-    (dir / 'loc1' / 'en' / 'LC_MESSAGES').makedirs()
-    (dir / 'loc1' / 'en' / 'LC_MESSAGES' / 'en_dom.po').write_text('#')
+def test_get_catalogs_for_en(tempdir):
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'xx_dom.po').write_text('#')
+    (tempdir / 'loc1' / 'en' / 'LC_MESSAGES').makedirs()
+    (tempdir / 'loc1' / 'en' / 'LC_MESSAGES' / 'en_dom.po').write_text('#')
 
-    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'en', force_all=False)
+    catalogs = i18n.find_catalog_source_files([tempdir / 'loc1'], 'en', force_all=False)
     domains = set(c.domain for c in catalogs)
     assert domains == set(['en_dom'])
 
 
-@with_tempdir
-def test_get_catalogs_with_non_existent_locale(dir):
-    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx')
+def test_get_catalogs_with_non_existent_locale(tempdir):
+    catalogs = i18n.find_catalog_source_files([tempdir / 'loc1'], 'xx')
     assert not catalogs
 
-    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], None)
+    catalogs = i18n.find_catalog_source_files([tempdir / 'loc1'], None)
     assert not catalogs
 
 
@@ -111,25 +104,24 @@ def test_get_catalogs_with_non_existent_locale_dirs():
     assert not catalogs
 
 
-@with_tempdir
-def test_get_catalogs_for_xx_without_outdated(dir):
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.mo').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test2.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test2.mo').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test3.pot').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test3.mo').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub').makedirs()
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test4.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test4.mo').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test5.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test5.mo').write_text('#')
+def test_get_catalogs_for_xx_without_outdated(tempdir):
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.mo').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test2.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test2.mo').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test3.pot').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test3.mo').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub').makedirs()
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test4.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test4.mo').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test5.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test5.mo').write_text('#')
 
-    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx', force_all=False)
+    catalogs = i18n.find_catalog_source_files([tempdir / 'loc1'], 'xx', force_all=False)
     assert not catalogs
 
-    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx', force_all=True)
+    catalogs = i18n.find_catalog_source_files([tempdir / 'loc1'], 'xx', force_all=True)
     domains = set(c.domain for c in catalogs)
     assert domains == set([
         'test1',
@@ -139,29 +131,27 @@ def test_get_catalogs_for_xx_without_outdated(dir):
     ])
 
 
-@with_tempdir
-def test_get_catalogs_from_multiple_locale_dirs(dir):
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
-    (dir / 'loc2' / 'xx' / 'LC_MESSAGES').makedirs()
-    (dir / 'loc2' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
-    (dir / 'loc2' / 'xx' / 'LC_MESSAGES' / 'test2.po').write_text('#')
+def test_get_catalogs_from_multiple_locale_dirs(tempdir):
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
+    (tempdir / 'loc2' / 'xx' / 'LC_MESSAGES').makedirs()
+    (tempdir / 'loc2' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
+    (tempdir / 'loc2' / 'xx' / 'LC_MESSAGES' / 'test2.po').write_text('#')
 
-    catalogs = i18n.find_catalog_source_files([dir / 'loc1', dir / 'loc2'], 'xx')
+    catalogs = i18n.find_catalog_source_files([tempdir / 'loc1', tempdir / 'loc2'], 'xx')
     domains = sorted(c.domain for c in catalogs)
     assert domains == ['test1', 'test1', 'test2']
 
 
-@with_tempdir
-def test_get_catalogs_with_compact(dir):
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test2.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub').makedirs()
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test3.po').write_text('#')
-    (dir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test4.po').write_text('#')
+def test_get_catalogs_with_compact(tempdir):
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES').makedirs()
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test1.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'test2.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub').makedirs()
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test3.po').write_text('#')
+    (tempdir / 'loc1' / 'xx' / 'LC_MESSAGES' / 'sub' / 'test4.po').write_text('#')
 
-    catalogs = i18n.find_catalog_source_files([dir / 'loc1'], 'xx', gettext_compact=True)
+    catalogs = i18n.find_catalog_source_files([tempdir / 'loc1'], 'xx', gettext_compact=True)
     domains = set(c.domain for c in catalogs)
     assert domains == set(['test1', 'test2', 'sub'])
 
@@ -214,9 +204,7 @@ def test_format_date():
     assert i18n.format_date(format, date=date) == 'Feb 7, 2016'
 
 
-def test_get_filename_for_language():
-    app = TestApp()
-
+def test_get_filename_for_language(app):
     # language is None
     app.env.config.language = None
     assert app.env.config.language is None
@@ -255,6 +243,19 @@ def test_get_filename_for_language():
         '../foo.png', app.env) == 'images/en/../foo.png'
     assert i18n.get_image_filename_for_language('foo', app.env) == 'images/en/foo'
 
+    # new path and basename tokens
+    app.env.config.language = 'en'
+    app.env.config.figure_language_filename = '{path}{language}/{basename}{ext}'
+    assert i18n.get_image_filename_for_language('foo.png', app.env) == 'en/foo.png'
+    assert i18n.get_image_filename_for_language(
+        'foo.bar.png', app.env) == 'en/foo.bar.png'
+    assert i18n.get_image_filename_for_language(
+        'subdir/foo.png', app.env) == 'subdir/en/foo.png'
+    assert i18n.get_image_filename_for_language(
+        '../foo.png', app.env) == '../en/foo.png'
+    assert i18n.get_image_filename_for_language('foo', app.env) == 'en/foo'
+
     # invalid figure_language_filename
     app.env.config.figure_language_filename = '{root}.{invalid}{ext}'
-    raises(SphinxError, i18n.get_image_filename_for_language, 'foo.png', app.env)
+    with pytest.raises(SphinxError):
+        i18n.get_image_filename_for_language('foo.png', app.env)
